from typing import Tuple, Dict
from domino_betting import DominoBet, Player
from datetime import datetime

class DominoGameInterface:
    def __init__(self):
        self.domino_bet = DominoBet()
        
    def register_player(self, username: str) -> str:
        player = Player(username)
        self.domino_bet.players[player.player_id] = player
        return player.player_id
    
    def add_funds(self, player_id: str, amount: float) -> bool:
        """Adicionar fundos via PIX"""
        return self.domino_bet.process_payment(player_id, amount)
    
    def create_game_lobby(self, game_type: str, bet_amount: float, creator_id: str) -> str:
        """Criar uma sala de jogo"""
        return self.domino_bet.create_game(game_type, bet_amount, [creator_id])
    
    def join_game(self, game_id: str, player_id: str) -> bool:
        """Entrar em um jogo existente"""
        game = self.domino_bet.current_games.get(game_id)
        if not game or game['status'] != 'waiting':
            return False
            
        if len(game['players']) >= {'1v1': 2, '2v2': 4, '4v4': 8}[game['type']]:
            return False
            
        if self.domino_bet.players[player_id].balance < game['bet_amount']:
            return False
            
        game['players'].append(player_id)
        return True 
    
    def start_game(self, game_id: str) -> bool:
        """Inicia o jogo quando todos os jogadores estiverem prontos"""
        return self.domino_bet.start_game(game_id)
    
    def make_move(self, game_id: str, player_id: str, piece: Tuple[int, int], position: str) -> bool:
        """Realiza uma jogada"""
        return self.domino_bet.make_move(game_id, player_id, piece, position)
    
    def draw_piece(self, game_id: str, player_id: str) -> bool:
        """Compra uma peça do monte"""
        return self.domino_bet.draw_piece(game_id, player_id)
    
    def get_game_state(self, game_id: str, player_id: str) -> Dict:
        """Retorna o estado atual do jogo para o jogador"""
        game = self.domino_bet.current_games.get(game_id)
        if not game or player_id not in game['players']:
            return None
            
        # Verificar se houve uma jogada recente do bot
        bot_move = game.get('last_bot_move', None)
        bot_just_played = False
        
        if bot_move:
            # Verificar se a jogada do bot foi nos últimos 3 segundos
            now = datetime.now().timestamp()
            if now - bot_move['timestamp'] < 3:
                bot_just_played = True
        
        return {
            'status': game['status'],
            'your_hand': game['hands'].get(player_id, []),
            'board_ends': game['board_ends'],
            'current_pieces': game['current_pieces'],
            'current_player': game['players'][game['current_player']],
            'is_your_turn': game['players'][game['current_player']] == player_id,
            'bot_just_played': bot_just_played,
            'bot_move': bot_move['piece'] if bot_just_played else None,
            'players': [
                {
                    'username': self.domino_bet.players[pid].username,
                    'pieces_count': len(game['hands'].get(pid, [])),
                    'is_bot': pid in self.domino_bet.bots
                }
                for pid in game['players']
            ]
        } 
    
    def create_bot_game(self, player_id: str, bet_amount: float, difficulty: str = 'normal') -> str:
        """Criar jogo contra bot"""
        return self.domino_bet.create_game_with_bot(player_id, bet_amount, difficulty) 